#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>

#define BUTTON  0
#define RELAY   5

const char* ssid = "NetworkName";
const char* password = "NetworkPassword";

ESP8266WebServer server(80);

//root page can be accessed only if authentification is ok
void handleRoot()
{
  char Page [512];

  int sec = millis() / 1000;
  int min = sec / 60;
  int hr = min / 60;
  
  if (server.hasArg("RELAY"))
  {
    digitalWrite (RELAY, !digitalRead(RELAY));  // Toggle relay
    Serial.println("Relay toggled");
  }
  
  snprintf ( Page, 512,
"<html>\
  <head>\
    <meta http-equiv='refresh' content='1'/>\
    <title>ESP8266 Demo</title>\
    <style>\
      body { background-color: #cccccc; font-family: Arial, Helvetica, Sans-Serif; Color: #000088; }\
    </style>\
  </head>\
  <body><form action='' method='POST'>\
    <h1>Hello from ESP8266-EVB!</h1>\
    <p>Uptime: %02d:%02d:%02d</p>\
    <input type='submit' name='RELAY' value='Toggle Relay'></form><br>\
    <p>Button: %d</p>\
  </body>\
</html>",

    hr, min % 60, sec % 60, digitalRead(0)
  );
  server.send(512, "text/html", Page);
}

void setup(void)
{
  pinMode (BUTTON, INPUT);
  pinMode (RELAY, OUTPUT);

  Serial.begin(115200);
  WiFi.begin(ssid, password);
  Serial.println("");

  // Wait for connection
  while (WiFi.status() != WL_CONNECTED)
  {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("Connected to ");
  Serial.println(ssid);
  Serial.print("IP address: ");
  Serial.println(WiFi.localIP());

  server.on("/", handleRoot);

  server.begin();
  Serial.println("HTTP server started");
}

void loop(void)
{
  server.handleClient();
}
